Documentation
¶
Index ¶
- type Iterator
- func (it *Iterator) Current() any
- func (it *Iterator) HasNext() bool
- func (it *Iterator) HasPrev() bool
- func (it *Iterator) Index() int
- func (it *Iterator) IsCycle() bool
- func (it *Iterator) Len() int
- func (it *Iterator) Next() any
- func (it *Iterator) Prev() any
- func (it *Iterator) Reset()
- func (it *Iterator) SetCycle(cycle bool)
- func (it *Iterator) SetIndex(index int) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Iterator ¶ added in v1.1.1
type Iterator struct {
// contains filtered or unexported fields
}
func (*Iterator) HasNext ¶ added in v1.1.1
HasNext returns true if the Iterator has a next item (always true if cycle mode is enabled)
func (*Iterator) HasPrev ¶ added in v1.1.1
HasPrev returns true if the Iterator has a previous item (always true if cycle mode is enabled)
func (*Iterator) Reset ¶ added in v1.1.1
func (it *Iterator) Reset()
Reset resets the Iterator to the beginning (nil item)
Click to show internal directories.
Click to hide internal directories.